@@ -1,16 +1,28 @@
-#!/usr/bin/python2.5
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 42 2011-12-18 17:11:03Z saturn $
+# $Id: smsconEditorMain.py 55 2011-12-20 19:28:44Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-#Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-#Contributions: Lutz Schwarz - refacturing to use common code in smsconlib.py
-Version = '0.9.4-1'
+#Contributor: Frank Visser - import, decrypt and encrypt from config file the user variables.
+#Contributor: Lutz Schwarz - refacturing, improvement of the code, as well as implement many new features.         
+
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published
+## by the Free Software Foundation; version 2 only.
+##
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+
+Version = '0.9.5-1'
 
 import os
 import sys
@@ -32,9 +44,10 @@ from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import *
 
-from smsconEditorMainGUI import *
+from smsconEditorStartup import *
 from smsconEditorAskPass import *
 from smsconEditorNewPass import *
+from smsconEditorMainGUI import *
 
 ##############################################################
 
@@ -46,8 +59,6 @@ FatalHelp       = 'Please contact SMSCON support team for a solution.'
 
 editConf        = UserConfiguration(Filename = os.path.join(TempPath, smscon.ConfigFile))
 
-##############################################################
-
 def commonPrefix(*args):
     """@return string The longest same string that all passed strings are starting with"""
     for idx in range(min(map(len, args))):
@@ -57,15 +68,11 @@ def commonPrefix(*args):
     if len(args):   return args[0]
     else:           return ''
 
-##############################################################
-
 def shellArg(s):
     """@return string The parameter s quoted to be safely used as a shell parameter."""
     s = s.replace("\'", "'\"'\"'")
     return "'%s'" % s
 
-##############################################################
-
 def showMessage(message):
     '''Display a message to the user and wait for confirmation.'''
 
@@ -73,8 +80,6 @@ def showMessage(message):
                 ' /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog' \
                 ' string:%s uint32:0 string:"OK"' % shellArg(message))
 
-##############################################################  
-
 def showQuickMessage(message):
     '''Display a message to the user and continue immediately.'''
 
@@ -82,8 +87,6 @@ def showQuickMessage(message):
                 ' /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint' \
                 ' string:%s' % shellArg(message))
 
-##############################################################  
-
 def showLogRecord(logRecord):
 
     msg = "%s: %s" % (logRecord.levelname, logRecord.msg)
@@ -94,16 +97,12 @@ def showLogRecord(logRecord):
 
 LOGGER = smscon.StartLogging('EDITOR', withConsole = False, withEmitterFxn = showLogRecord)
 
-##############################################################  
-
 def configYesNo(boolValue):
     return IF(boolValue, 'yes', 'no')
 
 def configTrue(yesNoValue):
     return yesNoValue == 'yes'
 
-##############################################################  
-
 def IsPasswordValid(password):  ### FIXME: what should be the behaviour if password is missing or empty?
     '''
     Check the given password.
@@ -125,8 +124,6 @@ def IsPasswordValid(password):  ### FIXME: what should be the behaviour if passw
 
     return os.popen('echo %s|md5sum -c "%s"' % (shellArg(password), PassFile)).read() == '-: OK\n'
 
-##############################################################  
-
 def CopyMainToEditConfig():
     '''
     Make a copy of the main configuration for safe editing.
@@ -176,8 +173,6 @@ def CopyMainToEditConfig():
         showMessage(message)
     return True
 
-##############################################################  
-
 def EditConfigAndApply(newConf, successMessage = None, errorMessage = None, startMessage = 'Updating. Please wait...'):
     '''
     Update editConf and replace the main config with it. Restart daemon.
@@ -200,9 +195,30 @@ def EditConfigAndApply(newConf, successMessage = None, errorMessage = None, star
             showMessage(errorMessage)
     return ok
 
-##############################################################
+class smsconEditorStartup(QtGui.QDialog):
+    '''Application start up dialog'''
+    
+    def __init__(self, parent=None):
+       ##Build the parent user interface
+       QtGui.QDialog.__init__(self, parent)
+       self.ui = Ui_smsconEditorStartup()
+       self.ui.setupUi(self)
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+       self.showFullScreen()
+       self.timer = QtCore.QBasicTimer()
+       self.step = 0       
+       self.timer.start(100, self)
 
-class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong password.
+    def timerEvent(self, event):
+
+       if self.step >= 100:
+          self.timer.stop()
+          self.close()
+       self.step = self.step + 1
+       self.ui.progressBarStart.setValue(self.step)
+
+class smsconEditorPasswordRequest(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong password.
     def __init__(self, parent=None):
 
         ##Build parent user interface
@@ -211,6 +227,7 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
         self.ui.setupUi(self)
         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        #self.showFullScreen()
         self.isInitialPasswordEntered = None
 
         ##Connect the button
@@ -232,8 +249,6 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
             EnteredPassword = self.ui.linePassword.text()
             if IsPasswordValid(EnteredPassword):
                 self.isInitialPasswordEntered = EnteredPassword == InitialPassword 
-                #message = 'Password correct'    -- superfluous message
-                #showQuickMessage(message)
                 return
         except:
             pass
@@ -246,9 +261,7 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
         showQuickMessage(message)
         sys.exit(1)
 
-##############################################################
-
-class MyMainWindow(QtGui.QMainWindow):
+class smsconEditorMainWindow(QtGui.QMainWindow):
     def __init__(self, parent=None):
 
         global editConf
@@ -260,26 +273,30 @@ class MyMainWindow(QtGui.QMainWindow):
             showQuickMessage('The initial password is %s' % InitialPassword)
 
         self.isSmsconTestActive = False
-
-        #Open Start Dialog - request password
-        mydialog = MyStartupDialog()
-        mydialog.exec_()
-
+        
+        ##Open Dialog - startup window
+        startupDialog = smsconEditorStartup()
+        startupDialog.exec_()
+        
+        ##Open Dialog - request password
+        passwordDialog = smsconEditorPasswordRequest()
+        passwordDialog.exec_()
+        
         if self.isUsersFirstTimeCall:
             message =   'Seems this is your first time here. You now should\n' \
                         '\n1. Edit settings to your needs.' \
                         '\n2. Check operation on "Test" tab.' \
                         '\n3. Enable SMSCON on device boot and' \
                         '\n4. Start SMSCON operation on "Init" tab.'
-            if mydialog.isInitialPasswordEntered:
+            if passwordDialog.isInitialPasswordEntered:
                 message += '\n\nAnd please go to "Change Password" and do so!'
             showMessage(message)
 
-        elif mydialog.isInitialPasswordEntered:
+        elif passwordDialog.isInitialPasswordEntered:
             message = 'Please go to "Change Password" and do so!'
             showMessage(message)
 
-        ##make a copy of the config for editing
+        ##Make a copy of the config for editing
         CopyMainToEditConfig()
         
         if editConf['SENDERNUMBER'] != editConf["MASTERNUMBER"]:
@@ -324,11 +341,11 @@ class MyMainWindow(QtGui.QMainWindow):
         ##Connect Menu Buttons 
         QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
-        QtCore.QObject.connect(self.ui.actionCredits, QtCore.SIGNAL('triggered()'), self.doCredits)
         QtCore.QObject.connect(self.ui.actionUpdate_Password, QtCore.SIGNAL('triggered()'), self.doUpdatePassword)
 
         ##Set values in the GUI.
-        self.SetValues()
+        self.SetConfigValues()
+        self.SetSystemValues()
 
     def closeEvent(self, event):
         """Cleanup on close."""
@@ -338,7 +355,7 @@ class MyMainWindow(QtGui.QMainWindow):
             showQuickMessage(message)
             self.doRestart();
 
-    def SetValues(self):
+    def SetConfigValues(self):
         '''Set GUI values from editConfig values'''
 
         global editConf
@@ -446,16 +463,32 @@ class MyMainWindow(QtGui.QMainWindow):
         self.ui.lineAlarm       .setText(comConf['COM_ALARM'])
         self.ui.lineRestart     .setText(comConf['COM_RESTART'])
 
+    def SetSystemValues(self):
+       '''Set GUI values from the current operation'''
+       
+       DAEMONSTATE = os.popen('sudo smscon -status').read().strip('\n') 
+       BOOTSTATE = IsFileReadable('/etc/event.d/smscon_boot')
+       
+       if DAEMONSTATE == 'Daemon smscon_daemon is running':
+          self.ui.btnStop.setEnabled(True)
+          self.ui.btnStop.setChecked(True)
+          self.ui.btnStart.setEnabled(False)
+       else:
+          self.ui.btnStart.setEnabled(True)
+          self.ui.btnStart.setChecked(True)
+          self.ui.btnStop.setEnabled(False)
+          
+       if BOOTSTATE:
+          self.ui.btnUnBoot.setEnabled(True)
+          self.ui.btnUnBoot.setChecked(True)
+          self.ui.btnBoot.setEnabled(False)
+       else:
+          self.ui.btnBoot.setEnabled(True)
+          self.ui.btnBoot.setChecked(True)
+          self.ui.btnUnBoot.setEnabled(False)
+          
     def doAbout(self):
-        self.aboutWin = SMSCONAbout(self)
-
-    def doCredits(self):
-        msg = unichr(int('00A9', 16)) + "SMSCON - 2010/2011, Frank Visser (digitalvoid)\n"
-        msg += "Control and Track your N900 through SMS\n\n"
-        msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010/2011, Christos Zamantzas (saturn)\n"
-        msg += "Configuration and Test user interface for the SMSCON daemon\n\n"
-        msg += "Distributed under GPL ver. 2"
-        QMessageBox.about(self, "Credits - SMSCON & SMSCON Editor", msg)
+        self.aboutWin = smsconEditorAbout(self)
 
     ##TAB: INIT
     def doInit(self):
@@ -497,24 +530,29 @@ class MyMainWindow(QtGui.QMainWindow):
             message = os.popen('sudo smscon -start 2>&1').read()
         self.isSmsconTestActive = False
         showMessage(message)
+        self.SetSystemValues()
 
     def doRestart(self):
         message = os.popen('sudo smscon -restart 2>&1').read()
         self.isSmsconTestActive = False
         showMessage(message)
+        self.SetSystemValues()
 
     def doStop(self):
         message = os.popen('sudo smscon -stop 2>&1').read()
         self.isSmsconTestActive = False
         showMessage(message)
+        self.SetSystemValues()
 
     def doBoot(self):
         message = os.popen('sudo smscon -boot 2>&1').read()
         showMessage(message)
+        self.SetSystemValues()
 
     def doUnBoot(self):
         message = os.popen('sudo smscon -unboot 2>&1').read()
         showMessage(message)
+        self.SetSystemValues()
 
     ##TAB: General    
     def doCreateConfigGeneral(self):
@@ -577,7 +615,6 @@ class MyMainWindow(QtGui.QMainWindow):
         EditConfigAndApply(newConf, message)
         
     ##TAB: Commands Renaming       
-      
     def doCreateConfigCommands(self):
 
         newConf = {}
@@ -643,6 +680,7 @@ class MyMainWindow(QtGui.QMainWindow):
                     '\nCheck interval: %s'  % newConf["CHECKTIME"]
         EditConfigAndApply(newConf, message)
 
+    ##TAB: TESTING        
     def smsconTest(self, testArgs, testTopic):
         """Initiate a SMSCON test using the given command line testArgs and given testTopic string."""
         if os.WEXITSTATUS(os.system('sudo smscon ' + testArgs)) == 0:
@@ -653,7 +691,6 @@ class MyMainWindow(QtGui.QMainWindow):
             message = 'Test initiation failed.'
             showMessage(message)
 
-    ##TAB: TESTING
     def doSendTestMail1(self):
         self.smsconTest('-test email1', 'An email should have been sent.')
         
@@ -680,12 +717,10 @@ class MyMainWindow(QtGui.QMainWindow):
       
     def doUpdatePassword(self):
         ##Open Dialog Window - change password
-        mydialog = MyPasswordDialog()
-        mydialog.exec_()
+        passwordChangeDialog = smsconEditorPasswordChange()
+        passwordChangeDialog.exec_()
 
-##############################################################  
-       
-class MyPasswordDialog(QtGui.QDialog):
+class smsconEditorPasswordChange(QtGui.QDialog):
 
     def __init__(self, parent=None):
         ##Build the parent user interface
@@ -729,94 +764,79 @@ class MyPasswordDialog(QtGui.QDialog):
         showMessage(message)
         self.close()
        
-##############################################################
-
-class SMSCONAbout(QtGui.QMainWindow):
+class smsconEditorAbout(QtGui.QMainWindow):
     '''About Window'''
+    
     def __init__(self, parent=None):
-        QMainWindow.__init__(self,parent)
-        self.parent = parent
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-        self.setWindowTitle("SMSCON Editor About")
+       QMainWindow.__init__(self,parent)
+       self.parent = parent
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+       self.setWindowTitle("SMSCON Editor About")
 
-        aboutScrollArea = QScrollArea(self)
-        aboutScrollArea.setWidgetResizable(True)
-        awidget = QWidget(aboutScrollArea)
-        awidget.setMinimumSize(470,1100)
-        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
-        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
-        #Kinetic scroller is available on Maemo and should be on meego
-        try:
-            scroller = aboutScrollArea.property("kineticScroller").toPyObject()
-            scroller.setEnabled(True)
-        except:
-            pass
+       aboutScrollArea = QScrollArea(self)
+       aboutScrollArea.setWidgetResizable(True)
+       awidget = QWidget(aboutScrollArea)
+       #awidget.setMinimumSize(470,1100)
+       awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+       aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+       try:
+          scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+          scroller.setEnabled(True)
+       except:
+          pass
 
-        aboutLayout = QVBoxLayout(awidget)
+       aboutLayout = QVBoxLayout(awidget)
 
-        aboutIcon = QLabel()
-        aboutIcon.setPixmap( QIcon.fromTheme('smscon-editor').pixmap(48,48) )
-        aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
-        aboutIcon.resize(128,128)
-        aboutLayout.addWidget(aboutIcon)
+       aboutIcon = QLabel()
+       aboutIcon.setPixmap( QIcon.fromTheme('smscon-editor').pixmap(128,128) )
+       aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+       aboutIcon.resize(128,128)
+       
+       aboutLayout.addWidget(aboutIcon)
+
+       aboutLabel = QLabel('''<center><b>SMSCON Editor</b><br>version: %s
+       <br><br><b>The SMSCON Editor is a user interface to assist in the initialisation, configuration and testing of SMSCON.</b>
+       <br><br>Licenced under GPLv2
+       <br>by <b>Christos Zamantzas</b> (Saturn)
+       <br><br>Besides editing options and modifing secret pass-phrases to control the phone, it allows to define email and sms contact, remote shell access (SSH) and a remote command server (HOST).
+       <br>
+       <br>For more details on usage and implications see the wiki pages (click buttons below).
+       <br>
+       <br><b>Thanks to:</b>
+       <br><b>Frank Visser</b> (Digitalvoid) for 
+       <br>for code to import, decrypt and encrypt the user variables from the configuration file.
+       <br><br><b>Lutz Schwarz</b> (schwarz.ware@gmx.de)
+       <br>for smsconlib, refacturing and improving the code as well as implementing many new features.
+       <br><br><b>Benoit HERVIER</b> at http://khertan.net/
+       <br>for code used in this about window.
+       <br></center>''' % Version)
+       
+       aboutLabel.setWordWrap(True)
+       aboutLabel.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+
+       aboutLayout.addWidget(aboutLabel)
+       self.wiki1_button = QPushButton('SMSCON')
+       self.wiki1_button.clicked.connect(self.open_wiki1)
+       self.wiki2_button = QPushButton('SMSCON Editor')
+       self.wiki2_button.clicked.connect(self.open_wiki2)
+       
+       awidget2 = QWidget()
+       buttonLayout = QHBoxLayout(awidget2)        
+       buttonLayout.addWidget(self.wiki1_button)
+       buttonLayout.addWidget(self.wiki2_button)
+       aboutLayout.addWidget(awidget2)
+
+       awidget.setLayout(aboutLayout)
+       aboutScrollArea.setWidget(awidget)
+       self.setCentralWidget(aboutScrollArea)
+       self.show()        
 
-        aboutLabel = QLabel('''<center><b>SMSCON Editor</b> 
-                               <br>version: ''' + str(Version) + '''
-                               <br>
-                               <b>SMSCON Editor is a user interface to 
-                               <br>initialise, configure and test SMSCON.</b>
-                               <br>
-                               <br>Licenced under GPLv2
-                               <br>by <b>Christos Zamantzas</b> (Saturn)
-                               <br>
-                               <br>Beside editing options and secret
-                               <br>pass-phrases to control the phone,
-                               <br>it allows to define
-                               <ul>
-                               <li>email and sms contact</li>
-                               <li>remote shell access (SSH) and a</li>
-                               <li>remote command server (HOST).</li>
-                               </ul>
-                               <br>
-                               <br>For details on usage and implications 
-                               <br>see wiki pages (click buttons below).
-                               <br>
-                               <br><b>Thanks to:</b>
-                               <br><b>Frank Visser</b> (Digitalvoid) for 
-                               <br>the code to import, decrypt and encrypt 
-                               <br>the user variables at the config file.
-                               <br>
-                               <br><b>Benoit HERVIER</b> at http://khertan.net/
-                               <br>for the code used in this about window.
-                               <br>
-                               <br><b>Lutz Schwarz</b> (schwarz.ware@gmx.de)
-                               <br>for smsconlib, refacturing and thereby
-                               <br>implementing many features.
-                               </center>''')
-        aboutLayout.addWidget(aboutLabel)
-        self.wiki1_button = QPushButton('SMSCON')
-        self.wiki1_button.clicked.connect(self.open_wiki1)
-        self.wiki2_button = QPushButton('SMSCON Editor')
-        self.wiki2_button.clicked.connect(self.open_wiki2)
-        awidget2 = QWidget()
-        buttonLayout = QHBoxLayout(awidget2)        
-        buttonLayout.addWidget(self.wiki1_button)
-        buttonLayout.addWidget(self.wiki2_button)
-        aboutLayout.addWidget(awidget2)
-        
-        awidget.setLayout(aboutLayout)
-        aboutScrollArea.setWidget(awidget)
-        self.setCentralWidget(aboutScrollArea)
-        self.show()        
-        
     def open_wiki1(self):
-        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON'))
+       QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON'))
 
     def open_wiki2(self):
-        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON_Editor'))
-
-##############################################################        
+       QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON_Editor'))
 
 class smsconEditorMain():
         
@@ -836,7 +856,7 @@ class smsconEditorMain():
 
     app = QtGui.QApplication(sys.argv)
     #Open Main Window
-    myapp = MyMainWindow()
+    myapp = smsconEditorMainWindow()
     myapp.show()
 
     sys.exit(app.exec_())
